## 股票收盘集合竞价数据

接口：stk_auction_c

描述：股票收盘15:00集合竞价数据，每天盘后更新

限量：单次请求最大返回10000行数据，可根据日期循环

权限：开通了股票分钟权限后可获得本接口权限，具体参考权限说明

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期(YYYYMMDD) |
| start_date | str | N | 开始日期(YYYYMMDD) |
| end_date | str | N | 结束日期(YYYYMMDD) |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_date | str | Y | 交易日期 |
| close | float | Y | 收盘集合竞价收盘价 |
| open | float | Y | 收盘集合竞价开盘价 |
| high | float | Y | 收盘集合竞价最高价 |
| low | float | Y | 收盘集合竞价最低价 |
| vol | float | Y | 收盘集合竞价成交量 |
| amount | float | Y | 收盘集合竞价成交额 |
| vwap | float | Y | 收盘集合竞价均价 |

接口用法

```python
pro = ts.pro_api()

df=pro.stk_auction_c(trade_date='20241122')
```

数据样例

```python
ts_code     trade_date close  ...   vol        amount      vwap
0     603102.SH   20241122  36.16  ...    557900.0   20347168.0  36.471
```